@@ -2,8 +2,9 @@
 #include "ui_mainwindow.h"
 #include <QDebug>
 #include "logindialog.h"
-
+#include <QMessageBox>
 #include <QLabel>
+#include <QtGui/QMenuBar>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -25,7 +26,11 @@ MainWindow::MainWindow(QWidget *parent) :
         f_user u = fsc->getUser();
         s->setSetting("userid",u.id);
     }
+    ui->pbFriends->setVisible(false); //TODO
 
+    QAction *aboutAction = new QAction(tr("About"), this);
+    menuBar()->addAction(aboutAction);
+    connect(aboutAction,SIGNAL(triggered(bool)),this,SLOT(showAbout()));
 }
 
 MainWindow::~MainWindow()
@@ -56,3 +61,8 @@ void MainWindow::on_pbTips_clicked()
     ntf = new NearbyTipsForm(this);
     ntf->show();
 }
+
+void MainWindow::showAbout()
+{
+    QMessageBox::information(this,"About FourCircle","<b>FourCircle</b><br>By Ted van den Brink<br><a href=\"mailto:ted@digistate.nl\">ted@digistate.nl</a><br>Thanks at:<br>Gilamonyet for the icon");
+}
