@@ -5,6 +5,10 @@
 #include "foursquarecomm.h"
 #include <QLabel>
 #include "checkindetails.h"
+#include "addtipdialog.h"
+#include <QtConcurrentRun>
+#include <QFutureWatcher>
+//#include <QThread>
 
 namespace Ui {
     class VenueDetails;
@@ -19,7 +23,7 @@ public:
     ~VenueDetails();
 public slots:
     void setVenue(f_venue v);
-    void getVenueDetails(QString id);
+    void venueIsReady();
 private:
     Ui::VenueDetails *ui;
     f_venue venue;
@@ -27,9 +31,14 @@ private:
     FoursquareComm * fsc;
     ImageCache * ic;
     CheckinDetails * cd;
+    AddTipDialog * atd;
+    static f_venue getVenueDetails(QString id);
 
+    QFuture<f_venue> *future;
+    QFutureWatcher<f_venue> *watcher;
 
 private slots:
+    void on_pbAddTip_clicked();
     void on_pbCheckin_clicked();
 };
 
